# TimeKeeper
Times Up Philosophy. "Think of yourself as dead. You have lived your life. Now, take what’s left and live it properly." You don't have time to waste, so prove that your not finding a way to waste it away.. 
